#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hakyll
version:              4.17.0.0
visibility:           public
id:                   hakyll-4.17.0.0-FwLMIh3uIf1CRzFqQEUSbP
key:                  hakyll-4.17.0.0-FwLMIh3uIf1CRzFqQEUSbP
license:              BSD-3-Clause
maintainer:           Jasper Van der Jeugt <m@jaspervdj.be>
author:               Jasper Van der Jeugt <m@jaspervdj.be>
homepage:             http://jaspervdj.be/hakyll
synopsis:             A static website compiler library
description:
    Hakyll is a static website compiler library. It provides you with the tools to
    create a simple or advanced static website using a Haskell DSL and formats
    such as markdown or RST. You can find more information, including a tutorial,
    on the website:

    * <http://jaspervdj.be/hakyll>

    If you seek assistance, there'\''s:

    * A google group: <http://groups.google.com/group/hakyll>

    * An IRC channel, @#hakyll@ on irc.libera.chat (we *do not* have a channel on Freenode anymore)

    Additionally, there'\''s the Haddock documentation in the different modules,
    meant as a reference.

category:             Web
abi:                  7a7c112cad437dc1f83fe7cc4be903ca
exposed:              True
exposed-modules:
    Hakyll Hakyll.Commands Hakyll.Core.Compiler
    Hakyll.Core.Compiler.Internal Hakyll.Core.Configuration
    Hakyll.Core.Dependencies Hakyll.Core.File Hakyll.Core.Identifier
    Hakyll.Core.Identifier.Pattern Hakyll.Core.Item Hakyll.Core.Logger
    Hakyll.Core.Metadata Hakyll.Core.Provider
    Hakyll.Core.Provider.Metadata Hakyll.Core.Routes Hakyll.Core.Rules
    Hakyll.Core.Rules.Internal Hakyll.Core.Runtime Hakyll.Core.Store
    Hakyll.Core.UnixFilter Hakyll.Core.Util.File
    Hakyll.Core.Util.String Hakyll.Core.Writable Hakyll.Main
    Hakyll.Web.CompressCss Hakyll.Web.Feed Hakyll.Web.Html
    Hakyll.Web.Html.RelativizeUrls Hakyll.Web.Meta.JSONLD
    Hakyll.Web.Meta.OpenGraph Hakyll.Web.Meta.TwitterCard
    Hakyll.Web.Paginate Hakyll.Web.Pandoc Hakyll.Web.Pandoc.Biblio
    Hakyll.Web.Pandoc.FileType Hakyll.Web.Redirect Hakyll.Web.Tags
    Hakyll.Web.Template Hakyll.Web.Template.Context
    Hakyll.Web.Template.Internal Hakyll.Web.Template.Internal.Element
    Hakyll.Web.Template.Internal.Trim Hakyll.Web.Template.List

hidden-modules:
    Data.List.Extended Data.Yaml.Extended Hakyll.Check
    Hakyll.Core.Compiler.Require
    Hakyll.Core.Identifier.Pattern.Internal Hakyll.Core.Item.SomeItem
    Hakyll.Core.Provider.Internal Hakyll.Core.Provider.MetadataCache
    Hakyll.Core.Util.Parser Paths_hakyll Hakyll.Preview.Poll
    Hakyll.Preview.Server Hakyll.Web.Pandoc.Binary

import-dirs:          /usr/lib/ghc-9.6.6/site-local/hakyll-4.17.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hakyll-4.17.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hakyll-4.17.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hakyll
hs-libraries:         HShakyll-4.17.0.0-FwLMIh3uIf1CRzFqQEUSbP
depends:
    aeson-2.2.2.0-3pjCpj5XtaHAHmzSwnt06z base-4.18.2.1 binary-0.8.9.1
    blaze-html-0.9.2.0-FHozDOQfWbTE40Bgc3es6n bytestring-0.11.5.3
    containers-0.6.7 contravariant-1.5.6-DrebhAx4XwC59wq9S42cYg
    data-default-0.7.1.3-6zOkPXxynjr15x05rRaNvG deepseq-1.4.8.1
    directory-1.3.8.5 file-embed-0.0.16.0-6A32wX7iXBC7ZTuLWlLLWz
    filepath-1.4.300.1 fsnotify-0.4.4.0-CeEazFCobkJF9t8pqOUlX
    hashable-1.4.7.0-KYRxVQLzygQHnYjqLKyJPN
    http-conduit-2.3.9.1-7x31A8Bvf12J6SDKAlTcxw
    http-types-0.12.4-FjxwRmZWhoR3wzry1r4T66
    lrucache-1.2.0.1-34e4rU2OpGtGXjnvLtyFkI mtl-2.3.1
    network-uri-2.6.4.2-2pvBC2E3r3ZG7itzgqfKfv
    optparse-applicative-0.18.1.0-5QX38E1JQlq4e4oHsAaFH0
    pandoc-3.10.2-8PCFOS0jtJy3HFs3BZo024
    pandoc-types-1.23.1.2-7r04FP2c39lATDnNYvBdb6 parsec-3.1.16.1
    process-1.6.19.0 random-1.2.1.3-FxwYxgjgoojJKMc450MWAC
    regex-tdfa-1.3.2.5-K3WM9QKkG8i6YZ8c6M2glc
    resourcet-1.3.0-G1Jndw6mtoEGFSzuHCFgbA
    scientific-0.3.8.1-H3VUewCJEy81jq03Pb0rn3
    tagsoup-0.14.8-DWOmiJXtEgX7eE3Elrwm1T template-haskell-2.20.0.0
    text-2.0.2 time-1.12.2
    time-locale-compat-0.1.1.5-8XUEctZKps57K6Zw5siYoh
    vector-0.13.2.0-9mJIQr0XJi1KVzSJMcMTkU
    wai-3.2.5-EjZd7LhAo0l7gnL0GV2ALc
    wai-app-static-3.1.9.1-Hm8Rq4XrdfR3uVNraUEamD
    warp-3.4.0-7tiR321zPRdKGpUQxxFcwZ
    xml-conduit-1.9.1.4-C84JdkwlC5a2lZXildVLnY
    yaml-0.11.11.2-LUugXbkeJApKC0qW2gmxvA

haddock-interfaces:   /usr/share/doc/haskell-hakyll/html/hakyll.haddock
haddock-html:         /usr/share/doc/haskell-hakyll/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

